FlutterLoadingOverlay class

Constructors

FlutterLoadingOverlay()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
init({required GlobalKey<NavigatorState> navigatorKey, Widget? customChild, double opacity = 0.5, Color overlayColor = Colors.black, Color? color}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startLoading() → void
stopLoading() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited